@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-# This file is part of Parti.
+# This file is part of Xpra.
 # Copyright (C) 2010-2013 Antoine Martin <antoine@devloop.org.uk>
-# Parti is released under the terms of the GNU GPL v2, or, at your option, any
+# Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 import sys, os
@@ -10,8 +10,7 @@ import gobject
 from xpra.sound.sound_pipeline import SoundPipeline, debug
 from xpra.sound.pulseaudio_util import has_pa
 from xpra.sound.gstreamer_util import plugin_str, get_encoder_formatter, MP3, CODECS
-from wimpiggy.util import n_arg_signal
-from wimpiggy.log import Logger
+from xpra.log import Logger
 log = Logger()
 
 
@@ -41,14 +40,15 @@ AUDIORESAMPLE = False
 
 class SoundSource(SoundPipeline):
 
-    __gsignals__ = {
-        "new-buffer": n_arg_signal(2),
-        }
+    __generic_signals__ = [
+        "new-buffer"
+        ]
 
     def __init__(self, src_type=DEFAULT_SRC, src_options={}, codec=MP3, encoder_options={}):
         assert src_type in SOURCES
         encoder, fmt = get_encoder_formatter(codec)
         SoundPipeline.__init__(self, codec)
+        self.add_signals(self.__generic_signals__)
         self.src_type = src_type
         source_str = plugin_str(src_type, src_options)
         encoder_str = plugin_str(encoder, encoder_options)
@@ -95,11 +95,12 @@ class SoundSource(SoundPipeline):
         #            "duration"  : buf.duration,
         #            "offset"    : buf.offset,
         #            "offset_end": buf.offset_end}
-        metadata = {}
+        metadata = {"timestamp" : buf.timestamp,
+                    "duration"  : buf.duration}
+        self.buffer_count += 1
+        self.byte_count += len(buf.data)
         self.emit("new-buffer", buf.data, metadata)
 
-gobject.type_register(SoundSource)
-
 
 def main():
     import os.path
